**********************************************
/*This do file replicates Figures 1 and 2 from
Even and Smith */ 

**********************************************

do z:\greek\do\directories.do
cd $dir_dta
use merged_sum_wint.dta, clear
drop if inelig_ch ==1
drop if intl ==1
drop if summer ==1 | winter ==1
do Z:\greek\do\graph_settings.do
	keep if enteringsem >="201010" /*only those in RD time-frame*/
	
gen wdf_grade = 0
replace wdf_grade = 1 if withdraw ==1 | d_grade ==1 | f_grade==1
label var wdf_grade "Course ends in withdraw, fail, or D"

gen ab_grade = b_grade==1 | a_grade==1
label var ab_grade "Course grade of an A or B"
	
global rd_vars grade normgrade ab_grade c_grade wdf_grade withdraw evergreek pledge1 eligible1a eligible1c ///
center_gpa1a center_gpa1c center_gpa_inter1a center_gpa_inter1c

***********************
*Figure 1. Discontinuity in Second Semester Pledging Probability
***********************
preserve
	collapse (mean) $rd_vars gpa_cat1c_bin05, by(dummyid) 
	reg pledge1 eligible1c center_gpa1c center_gpa_inter1c if center_gpa1c >=float(-.40) & center_gpa1c<=float(.40)
	predict pledge1fit
	egen pledge1_cat_avg = mean(pledge1), by(gpa_cat1c_bin05) 

	twoway (scatter pledge1_cat_avg gpa_cat1c_bin05 if center_gpa1c>=-.4 & center_gpa1c<=.4, xline(0) xlab(-.4 (.2) .4)) ///
	(lfit pledge1fit center_gpa1c if center_gpa1c>=-.4 & center_gpa1c<0) ///
	(lfit pledge1fit center_gpa1c if center_gpa1c>=0 & center_gpa1c<=.4) ///
	,xtitle("GPA relative to eligibility criteria") ytitle("Pledge Second Semester") legend(off) 
	graph export ${dir_gph}\Figure1.pdf, replace
restore



***********************
*Reduced Form - grades on eligibility: 2010+ sample
***********************


*Figure 2. Panel A. Discontinuity in Normalized Grade
preserve
	keep if exper >=1 & exper<12 & enteringsem>="201010"
	reg normgrade eligible1c center_gpa1c center_gpa_inter1c [aw=credithours] if center_gpa1c >=float(-.40) & center_gpa1c<=float(.40)
	predict normgradefit
	egen gpa_cat_avg = wtmean(normgrade), weight(credithours) by(gpa_cat1c_bin05) /*weighted avg. of subsequent GPA*/

		twoway (scatter gpa_cat_avg gpa_cat1c_bin05 if center_gpa1c>=-.4 & center_gpa1c<=.4, xline(0) xlab(-.4 (.2) .4)) ///
	(lfit normgradefit center_gpa1c if center_gpa1c>=-.4 & center_gpa1c<0) ///
	(lfit normgradefit center_gpa1c if center_gpa1c>=0 & center_gpa1c<=.4) ///
	,xtitle("GPA relative to eligibility criteria") ytitle("Normalized Course Grade") legend(off)
	graph export ${dir_gph}\RD_normgrade_bin05_fit.pdf, replace
	graph save ${dir_gph}\RD_normgrade_bin05fit, replace
restore	

*Figure 2. Panel B. Discontinuity in Grade Point
preserve
	keep if exper >=1 & exper<12 & enteringsem>="201010"
	reg grade eligible1c center_gpa1c center_gpa_inter1c [aw=credithours] if center_gpa1c >=float(-.40) & center_gpa1c<=float(.40)
	predict gradefit
	egen gpa_cat_avg = wtmean(grade), weight(credithours) by(gpa_cat1c_bin05) /*weighted avg. of subsequent GPA*/

		twoway (scatter gpa_cat_avg gpa_cat1c_bin05 if center_gpa1c>=-.4 & center_gpa1c<=.4, xline(0) xlab(-.4 (.2) .4)) ///
	(lfit gradefit center_gpa1c if center_gpa1c>=-.4 & center_gpa1c<0) ///
	(lfit gradefit center_gpa1c if center_gpa1c>=0 & center_gpa1c<=.4) ///
	,xtitle("GPA relative to eligibility criteria") ytitle("Grade Point") legend(off)
	graph export ${dir_gph}\RD_grade_bin05_fit.pdf, replace
	graph save ${dir_gph}\RD_grade_bin05fit, replace
restore	

*Figure 2. Panel C. Discontinuity in A or B grade
preserve
	keep if exper >=1 & exper<12 & enteringsem>="201010"
	reg ab_grade eligible1c center_gpa1c center_gpa_inter1c [aw=credithours] if center_gpa1c >=float(-.40) & center_gpa1c<=float(.40)
	predict ab_gradefit
	egen gpa_cat_avg = wtmean(ab_grade), weight(credithours) by(gpa_cat1c_bin05) /*weighted avg. of subsequent GPA*/

		twoway (scatter gpa_cat_avg gpa_cat1c_bin05 if center_gpa1c>=-.4 & center_gpa1c<=.4, xline(0) xlab(-.4 (.2) .4)) ///
	(lfit ab_gradefit center_gpa1c if center_gpa1c>=-.4 & center_gpa1c<0) ///
	(lfit ab_gradefit center_gpa1c if center_gpa1c>=0 & center_gpa1c<=.4) ///
	,xtitle("GPA relative to eligibility criteria") ytitle("A or B grade") legend(off)
	graph export ${dir_gph}\RD_ab_grade_full1c_bin05_fit.pdf, replace
	graph save ${dir_gph}\RD_ab_grade_bin05fit, replace
restore	

*Figure 2. Panel D. Discontinuity in Withdraw D or F grade
preserve
	keep if exper >=1 & exper<12 & enteringsem>="201010"
	reg wdf_grade eligible1c center_gpa1c center_gpa_inter1c [aw=credithours] if center_gpa1c >=float(-.40) & center_gpa1c<=float(.40)
	predict wdf_gradefit
	egen gpa_cat_avg = wtmean(wdf_grade), weight(credithours) by(gpa_cat1c_bin05) /*weighted avg. of subsequent GPA*/
		twoway (scatter gpa_cat_avg gpa_cat1c_bin05 if center_gpa1c>=-.4 & center_gpa1c<=.4, xline(0) xlab(-.4 (.2) .4)) ///
	(lfit wdf_gradefit center_gpa1c if center_gpa1c>=-.4 & center_gpa1c<0) ///
	(lfit wdf_gradefit center_gpa1c if center_gpa1c>=0 & center_gpa1c<=.4) ///
	,xtitle("GPA relative to eligibility criteria") ytitle("Withdraw, D, or F grade") legend(off)
	graph export ${dir_gph}\RD_wdf_grade_bin05_fit.pdf, replace
	graph save ${dir_gph}\RD_wdf_grade_bin05fit, replace
restore	

*************************
* Figure 2. Discontinuities in Subsequent Course Grades
*************************
graph combine ${dir_gph}\RD_normgrade_bin05fit.gph  ${dir_gph}\RD_grade_bin05fit.gph ${dir_gph}\RD_ab_grade_bin05fit.gph ${dir_gph}\RD_wdf_grade_bin05fit.gph, /// 
 ysize(6) xsize(6) col(2) altshrink
graph export ${dir_gph}\Figure2.pdf, replace



capture log close





