

/********************************************************************************
			This do-file does the Regression Discontinuity analysis in Table 9 
			with Bounding akin to Lee 2009.   
		
*********************************************************************************/

clear all
qui do Z:\greek\do\directories.do
cd $dir_dta
capture log close



/*******LOAD SAMPLE BOUNDING PROGRAM**********************/
capture program drop sample_bound
program define sample_bound, eclass
di "sample_bound"
capture drop random 
gen random=runiform(0,1000)
replace random=1001 if ${y}_resp==0 | eligible1c==0  /*identify obs not eligible to be dropped*/
sort random
local tolerance=$tolerance
local b=.1

local ndropped=0
while abs(`b')>`tolerance' {
qui drop if _n<=$nsize
qui reg ${y}_resp eligible1c center_gpa1c center_gpa_inter1c $emp_controls, cluster(center_gpa1c)	
local b=_b[eligible1c]
local ndropped=`ndropped'+$nsize
global ndropped "`ndropped'" 
*display "beta  `b'"
}
*display "number of obs dropped `ndropped'" 

end	

/********************************************************************************
			Regression Discontinuity Analysis with Bounding akin to Lee 2009
			
			
*********************************************************************************/
use ${dir_dta}\merged_sum_wint_by_stdnt_w_salary.dta, clear
drop if inelig_ch ==1
keep if enteringsem>="201010" /*just keep RD sample*/ 
drop if intl ==1 /*dropping international students */

gen grad_3point = grad_gpa>=3 if grad_gpa!=.
gen cohort = substr(enteringsem, 1, 4) /*creating a new variable for year entered*/
destring cohort, replace
gen final_3point = final_gpa>=3

global rd_vars grade normgrade withdraw evergreek pledge1 eligible1a eligible1b eligible1c ///
center_gpa1a center_gpa1b center_gpa1c center_gpa_inter1a center_gpa_inter1b center_gpa_inter1c

global lab_outcome "employed fulltime salary_midpt lnsal_hat_grad_maj"
global educ_outcome "retention fouryr_grad fiveyr_grad sixyr_grad grad_gpa final_gpa gpa_norm grad_3point final_3point same_major awstem enrolled_grad"
global educ_controls "female bestact dom_min enteringage resident need_hi_med"
global lab_other "degree_fall degree_spring degree_winter degree_summer enter_div enter_area infield hourly ft_stat log_sal high_sal grad_universe sal_resp emp_resp survey_year"
global emp_controls "female bestact dom_minor resident need_hi_med enteringage i.survey_year degree_fall degree_spring degree_winter degree_summer i.enter_area"

egen num_sem = count(exper), by(dummyid)
label var num_sem "number of semesters student present in sample"
	
collapse num_sem pledge1 eligible1c center_gpa1c center_gpa_inter1c cohort enrolled_undergrad $lab_outcome $educ_outcome $educ_controls $lab_other, by(dummyid)  /*collapse data to the individual level*/

/********************************************************************************
Set parameters for bounding exercise			
*********************************************************************************/

set seed 12345
global tolerance ".005" 
global nsize "1"     /*number of observations dropped each draw"*/
global ndraws "500"   /*number of draws*/
global y "log_sal"   /*employed, fulltime, or log_sal*/
global ols "1"		  /*0 or 1: estimate model as ols instead of rd*/
log using $dir_log\rd_lee_bounds_${y}_${ols}, replace


if "$y"=="employed" & "$ols"=="0" {
	keep if enrolled_grad !=1 & enrolled_undergrad !=1  & center_gpa1c >=float(-.40) & center_gpa1c<=float(.40)
}
if "$y"=="log_sal" & "$ols"=="0" {
	keep if enrolled_grad !=1 & enrolled_undergrad !=1 & ft_stat ==1 & center_gpa1c >=float(-.40) & center_gpa1c<=float(.40)
}
if "$y"=="log_sal" & "$ols"=="1" {
	keep if enrolled_grad !=1 & enrolled_undergrad !=1 & ft_stat ==1 
}


if "$y"=="fulltime" & "$ols"=="0" {
	keep if center_gpa1c >=float(-.40) & center_gpa1c<=float(.40) & enrolled_grad !=1 & enrolled_undergrad !=1
}



gen log_sal_resp=log_sal~=.
gen employed_resp=employed~=.
gen fulltime_resp=fulltime~=.

capture erase bounding_${y}_ols${ols}.dta
if "${ols}"=="0" {
ivreg2 $y (pledge1=eligible1c) center_gpa1c center_gpa_inter1c $emp_controls, cluster(center_gpa1c)
}
if "${ols}"=="1" {
reg $y pledge1 $emp_controls, cluster(center_gpa1c)
}
local b=_b[pledge1]
local main=1
local ndropped=0
local nobs=e(N)
postfile myres b ndropped nobs main using ${dir_dta}/bounding_${y}_ols${ols}.dta
post myres (`b') (`ndropped') (`nobs') (`main')


forvalues i=1/$ndraws {
di "iteration `i' for ${y}"
preserve
qui sample_bound
global nobs=_N
display "number of obs in regression $nobs"
if "${ols}"=="0" {
	ivreg2 $y (pledge1=eligible1c) center_gpa1c center_gpa_inter1c $emp_controls, cluster(center_gpa1c)
}
if "${ols}"=="1" {
	reg $y pledge1 center_gpa1c center_gpa_inter1c $emp_controls, cluster(center_gpa1c)
}
local b=_b[pledge1]
local main=0
local ndropped=$ndropped
local nobs=$nobs
post myres (`b') (`ndropped') (`nobs') (`main')
restore
local i=`i'+1
}
postclose myres

use ${dir_dta}/bounding_${y}_ols${ols}.dta, clear
di "b with full sample"
sum b if main==1
drop if main==1
qui sum b
di "mean of coefficient estimates" 
di r(mean)
_pctile b, nq(200)
di "95% confidence intervals for b"
di r(r5) r(r195)
 