/*==============================================================================
THIS DO FILE CREATES THE SUMMARY STATISTICS IN TABLE 1
==============================================================================*/


do z:\greek\do\directories.do
cd $dir_dta
capture log close
log using $dir_log\means, replace
use merged_sum_wint.dta, clear
keep if inelig_ch==0  /*drop those not eligbile based on 1st semester credit hours*/ 
drop if intl==1
drop if bestactequivalent==.
drop if winter==1 | summer==1

capture erase means_by_greek.csv


/*variables by student for Greek only*/
gen z=grk_susp_midsem+grk_susp_ongoing
bysort dummyid: egen eversusp=max(z) if evergreek==1
drop z
gen z=evergreek==1 & exper==1 & grk_pledge==1
bysort dummyid: egen pledge_in_first=max(z) if evergreek==1
bysort dummyid: egen ever_rem=max(grk_rem)if evergreek==1

/*varaibles with means weighted by course credit hours*/
global x1 "term_gpa normgrade"  

/*variables with means weighted by semester*/
global x2 "bestact complete_credit resident need_hi_med female intl dom_minor dom_nonminor athlete evergreek pledge_in_first eversusp ever_rem" 

/*compute std of grades in typical course*/
bysort courseid: egen sd=sd(grade) 

preserve
collapse (mean) $x1 [aw=credithours], by(dummyid)
save temp1.dta, replace
restore
preserve
collapse (mean) $x2 , by(dummyid)
merge 1:1 dummyid using temp1.dta
save temp1.dta, replace
restore 

label data "one observation per student with summer/winter terms dropped*/
use temp1.dta, clear
forvalue f=0/1 {
tabstat ${x1} ${x2} if female==`f', stat(mean) by(evergreek) save

	matrix mean_`f'=r(Stat1)' , r(Stat2)'
	matrix list mean_`f'
	tabstat dummyid if female==`f', stat(count) by(evergreek) save
	matrix n_`f'=r(Stat1) , r(Stat2)
	matrix list n_`f'
	}
	tabstat $x1 $x2, stat(count)  save
	matrix nvar=r(StatTotal)' 
	
	matrix mean_1diff=mean_1[1...,2]-mean_1[1...,1]
	matrix list mean_1diff
	matrix mean_0diff=mean_0[1...,2]-mean_0[1...,1]
	matrix mean= mean_1, mean_1diff, mean_0, mean_0diff, nvar
	matrix n=n_1, 0, n_0, 0, 0
	matrix mean=mean \ n
	matrix colnames mean = Female_NGrk  Female_Grk  Diff Male_NGrk  Male_Grk Diff N
	matrix list mean, format(%8.2f)
	
*********PUT VARIABLE LABELS INTO ROW NAMES*********************
do ${dir_do}\labels.do
local rows 
foreach var of varlist $x1 $x2   {
 local x = strtoname("`: variable label `var''")
 local rows `rows' `x'
 }
 matrix rownames mean=`rows' "Sample Size" 
/*
 
do z:\do\labels.do
local rows 
display "start"
display `rows'
foreach var of varlist $x1 $x2   {
 local x: variable label `var'
 display "`x'"
 local rows `rows' "`""`x'""'"
 display `rows'
 mat rownames mean = `rows'
 *mat mean=mean[2...,1...]  /*remove first empty row*/
*matrix list mean
 }
global rows `rows'

 display "`rows'"
 mat rownames mean = `rows'
 *mat mean=mean[2...,1...]  /*remove first empty row*/
 matrix list mean
*/
 cd ${dir_results}
	
putexcel set grk_mns, replace
putexcel A1=matrix(mean), names 
capture log close

	
